# datastore-viewer

datastore-viewer is a simple viewer of Google Cloud Datastore Emulator.

## Installing

```bash
$ pip install --upgrade datastore-viewer
```

## Running

```bash
datastore-viewer
```

or

```bash
export DATASTORE_VIEWER_HOST=127.0.0.1
export DATASTORE_VIEWER_PORT=8082
datastore-viewer
```
